Task: Dialog Based Language Learning: WikiMovies Task
======================================================
Description: Short dialogs based on WikiMovies, but in the form of a question from a teacher, the answer from the student, and finally a comment on the answer from the teacher. The aim is to find learning models that use the comments to improve. From Weston '16. 

Link: https://arxiv.org/abs/1604.06045

Tags: #DBLL-Movie, #All, #Goal

